@@ -1,5 +1,25 @@
 package SQL::Translator::Parser::Access;
 
+# -------------------------------------------------------------------
+# $Id: Access.pm,v 1.2 2004/07/30 21:56:18 kycl4rk Exp $
+# -------------------------------------------------------------------
+# Copyright (C) 2002-4 SQLFairy Authors
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation; version 2.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+# 02111-1307  USA
+# -------------------------------------------------------------------
+
 =head1 NAME
 
 SQL::Translator::Parser::Access - parser for Access as produced by mdbtools
@@ -14,34 +34,37 @@ SQL::Translator::Parser::Access - parser for Access as produced by mdbtools
 
 =head1 DESCRIPTION
 
-The grammar derived from the MySQL grammar.  The input is expected to be
+The grammar derived from the MySQL grammar.  The input is expected to be 
 something similar to the output of mdbtools (http://mdbtools.sourceforge.net/).
 
 =cut
 
 use strict;
-use warnings;
-
-our $VERSION = '1.59';
-
-our $DEBUG;
-$DEBUG = 0 unless defined $DEBUG;
+use vars qw[ $DEBUG $VERSION $GRAMMAR @EXPORT_OK ];
+$VERSION = sprintf "%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/;
+$DEBUG   = 0 unless defined $DEBUG;
 
 use Data::Dumper;
-use SQL::Translator::Utils qw/ddl_parser_instance/;
-
+use Parse::RecDescent;
+use Exporter;
 use base qw(Exporter);
-our @EXPORT_OK = qw(parse);
 
-our $GRAMMAR = <<'END_OF_GRAMMAR';
+@EXPORT_OK = qw(parse);
 
-{
+# Enable warnings within the Parse::RecDescent module.
+$::RD_ERRORS = 1; # Make sure the parser dies when it encounters an error
+$::RD_WARN   = 1; # Enable warnings. This will warn on unused rules &c.
+$::RD_HINT   = 1; # Give out hints to help fix problems.
+
+$GRAMMAR = q!
+
+{ 
     my ( %tables, $table_order, @table_comments );
 }
 
 #
 # The "eofile" rule makes the parser fail if any "statement" rule
-# fails.  Otherwise, the first successful match by a "statement"
+# fails.  Otherwise, the first successful match by a "statement" 
 # won't cause the failure needed to know that the parse, as a whole,
 # failed. -ky
 #
@@ -71,7 +94,7 @@ create : CREATE /database/i WORD ';'
     { @table_comments = () }
 
 create : CREATE TABLE table_name '(' create_definition(s /,/) ')' ';'
-    {
+    { 
         my $table_name                       = $item{'table_name'};
         $tables{ $table_name }{'order'}      = ++$table_order;
         $tables{ $table_name }{'table_name'} = $table_name;
@@ -85,10 +108,10 @@ create : CREATE TABLE table_name '(' create_definition(s /,/) ')' ';'
         for my $definition ( @{ $item[5] } ) {
             if ( $definition->{'supertype'} eq 'field' ) {
                 my $field_name = $definition->{'name'};
-                $tables{ $table_name }{'fields'}{ $field_name } =
+                $tables{ $table_name }{'fields'}{ $field_name } = 
                     { %$definition, order => $i };
                 $i++;
-
+        
                 if ( $definition->{'is_primary_key'} ) {
                     push @{ $tables{ $table_name }{'constraints'} },
                         {
@@ -121,64 +144,64 @@ create : CREATE UNIQUE(?) /(index|key)/i index_name /on/i table_name '(' field_n
         ;
     }
 
-create_definition : constraint
+create_definition : constraint 
     | index
     | field
     | comment
     | <error>
 
-comment : /^\s*--(.*)\n/
-    {
+comment : /^\s*--(.*)\n/ 
+    { 
         my $comment =  $1;
         $return     = $comment;
         push @table_comments, $comment;
     }
 
 field : field_name data_type field_qualifier(s?) reference_definition(?)
-    {
-        $return = {
+    { 
+        $return = { 
             supertype   => 'field',
-            name        => $item{'field_name'},
+            name        => $item{'field_name'}, 
             data_type   => $item{'data_type'}{'type'},
             size        => $item{'data_type'}{'size'},
             constraints => $item{'reference_definition(?)'},
-        }
+        } 
     }
     | <error>
 
 field_qualifier : not_null
-    {
-        $return = {
+    { 
+        $return = { 
              null => $item{'not_null'},
-        }
+        } 
     }
 
 field_qualifier : default_val
-    {
-        $return = {
+    { 
+        $return = { 
              default => $item{'default_val'},
-        }
+        } 
     }
 
 field_qualifier : auto_inc
-    {
-        $return = {
+    { 
+        $return = { 
              is_auto_inc => $item{'auto_inc'},
-        }
+        } 
     }
 
 field_qualifier : primary_key
-    {
-        $return = {
+    { 
+        $return = { 
              is_primary_key => $item{'primary_key'},
-        }
+        } 
     }
 
 field_qualifier : unsigned
-    {
-        $return = {
+    { 
+        $return = { 
              is_unsigned => $item{'unsigned'},
-        }
+        } 
     }
 
 field_qualifier : /character set/i WORD
@@ -188,15 +211,15 @@ field_qualifier : /character set/i WORD
         }
     }
 
-reference_definition : /references/i table_name parens_field_list(?) match_type(?) on_delete(?) on_update(?)
+reference_definition : /references/i table_name parens_field_list(?) match_type(?) on_delete_do(?) on_update_do(?)
     {
         $return = {
             type             => 'foreign_key',
             reference_table  => $item[2],
             reference_fields => $item[3][0],
             match_type       => $item[4][0],
-            on_delete        => $item[5][0],
-            on_update        => $item[6][0],
+            on_delete_do     => $item[5][0],
+            on_update_do     => $item[6][0],
         }
     }
 
@@ -204,18 +227,18 @@ match_type : /match full/i { 'full' }
     |
     /match partial/i { 'partial' }
 
-on_delete : /on delete/i reference_option
+on_delete_do : /on delete/i reference_option
     { $item[2] }
 
-on_update : /on update/i reference_option
+on_update_do : /on update/i reference_option
     { $item[2] }
 
-reference_option: /restrict/i |
-    /cascade/i   |
-    /set null/i  |
-    /no action/i |
+reference_option: /restrict/i | 
+    /cascade/i   | 
+    /set null/i  | 
+    /no action/i | 
     /set default/i
-    { $item[1] }
+    { $item[1] }  
 
 index : normal_index
     | fulltext_index
@@ -228,12 +251,12 @@ field_name   : NAME
 index_name   : NAME
 
 data_type    : access_data_type parens_value_list(s?) type_qualifier(s?)
-    {
-        $return        = {
+    { 
+        $return        = { 
             type       => $item[1],
             size       => $item[2][0],
             qualifiers => $item[3],
-        }
+        } 
     }
 
 access_data_type : /long integer/i { $return = 'Long Integer' }
@@ -259,7 +282,7 @@ not_null     : /not/i /null/i { $return = 0 }
 
 unsigned     : /unsigned/i { $return = 0 }
 
-default_val : /default/i /'(?:.*?\')*.*?'|(?:')?[\w\d:.-]*(?:')?/
+default_val : /default/i /'(?:.*?\\')*.*?'|(?:')?[\w\d:.-]*(?:')?/
     {
         $item[2] =~ s/^\s*'|'\s*$//g;
         $return  =  $item[2];
@@ -285,7 +308,7 @@ foreign_key_def : foreign_key_def_begin parens_field_list reference_definition
         }
     }
 
-foreign_key_def_begin : /constraint/i /foreign key/i
+foreign_key_def_begin : /constraint/i /foreign key/i 
     { $return = '' }
     |
     /constraint/i WORD /foreign key/i
@@ -295,8 +318,8 @@ foreign_key_def_begin : /constraint/i /foreign key/i
     { $return = '' }
 
 primary_key_def : primary_key index_name(?) '(' name_with_opt_paren(s /,/) ')'
-    {
-        $return       = {
+    { 
+        $return       = { 
             supertype => 'constraint',
             name      => $item{'index_name(?)'}[0],
             type      => 'primary_key',
@@ -305,33 +328,33 @@ primary_key_def : primary_key index_name(?) '(' name_with_opt_paren(s /,/) ')'
     }
 
 unique_key_def : UNIQUE KEY(?) index_name(?) '(' name_with_opt_paren(s /,/) ')'
-    {
-        $return       = {
+    { 
+        $return       = { 
             supertype => 'constraint',
             name      => $item{'index_name(?)'}[0],
             type      => 'unique',
             fields    => $item[5],
-        }
+        } 
     }
 
 normal_index : KEY index_name(?) '(' name_with_opt_paren(s /,/) ')'
-    {
-        $return       = {
+    { 
+        $return       = { 
             supertype => 'index',
             type      => 'normal',
             name      => $item{'index_name(?)'}[0],
             fields    => $item[4],
-        }
+        } 
     }
 
 fulltext_index : /fulltext/i KEY(?) index_name(?) '(' name_with_opt_paren(s /,/) ')'
-    {
-        $return       = {
+    { 
+        $return       = { 
             supertype => 'index',
             type      => 'fulltext',
             name      => $item{'index_name(?)'}[0],
             fields    => $item[5],
-        }
+        } 
     }
 
 name_with_opt_paren : NAME parens_value_list(s?)
@@ -342,7 +365,7 @@ UNIQUE : /unique/i { 1 }
 KEY : /key/i | /index/i
 
 table_option : WORD /\s*=\s*/ WORD
-    {
+    { 
         $return = { $item[1] => $item[3] };
     }
 
@@ -365,9 +388,9 @@ NAME    : "`" /\w+/ "`"
 
 VALUE   : /[-+]?\.?\d+(?:[eE]\d+)?/
     { $item[1] }
-    | /'.*?'/
-    {
-        # remove leading/trailing quotes
+    | /'.*?'/   
+    { 
+        # remove leading/trailing quotes 
         my $val = $item[1];
         $val    =~ s/^['"]|['"]$//g;
         $return = $val;
@@ -375,40 +398,40 @@ VALUE   : /[-+]?\.?\d+(?:[eE]\d+)?/
     | /NULL/
     { 'NULL' }
 
-END_OF_GRAMMAR
+!;
 
+# -------------------------------------------------------------------
 sub parse {
     my ( $translator, $data ) = @_;
-
-    # Enable warnings within the Parse::RecDescent module.
-    local $::RD_ERRORS = 1 unless defined $::RD_ERRORS; # Make sure the parser dies when it encounters an error
-    local $::RD_WARN   = 1 unless defined $::RD_WARN; # Enable warnings. This will warn on unused rules &c.
-    local $::RD_HINT   = 1 unless defined $::RD_HINT; # Give out hints to help fix problems.
+    my $parser = Parse::RecDescent->new($GRAMMAR);
 
     local $::RD_TRACE  = $translator->trace ? 1 : undef;
     local $DEBUG       = $translator->debug;
 
-    my $parser = ddl_parser_instance('Access');
+    unless (defined $parser) {
+        return $translator->error("Error instantiating Parse::RecDescent ".
+            "instance: Bad grammer");
+    }
 
     my $result = $parser->startrule($data);
     return $translator->error( "Parse failed." ) unless defined $result;
     warn Dumper( $result ) if $DEBUG;
 
     my $schema = $translator->schema;
-    my @tables = sort {
+    my @tables = sort { 
         $result->{ $a }->{'order'} <=> $result->{ $b }->{'order'}
     } keys %{ $result };
 
     for my $table_name ( @tables ) {
         my $tdata =  $result->{ $table_name };
-        my $table =  $schema->add_table(
+        my $table =  $schema->add_table( 
             name  => $tdata->{'table_name'},
         ) or die $schema->error;
 
         $table->comments( $tdata->{'comments'} );
 
-        my @fields = sort {
-            $tdata->{'fields'}->{$a}->{'order'}
+        my @fields = sort { 
+            $tdata->{'fields'}->{$a}->{'order'} 
             <=>
             $tdata->{'fields'}->{$b}->{'order'}
         } keys %{ $tdata->{'fields'} };
